@@ -106,7 +106,7 @@ bytestr_fmt={
   'c_void_p': 'P'
   }
 def array2bytes_(array, typ):
-  arrayLen=len(array)
+  arrayLen = len(array)
   if arrayLen == 0:
     return b''
   if typ not in bytestr_fmt:
@@ -164,19 +164,21 @@ def isStructType(obj):
 def isPointerType(obj):
   if isBasicType(obj) or isStructType(obj):
     return False
-  return type(obj).__class__.__name__== 'PointerType'
+  return 'PointerType' in type(obj).__class__.__name__ 
 
 def isBasicTypeArrayType(obj):
   if isArrayType(obj):
+    if len(obj) == 0:
+      return True
     if isBasicType(obj[0]):
       return True
   return False
 
 def isArrayType(obj):
-  return type(obj).__class__.__name__=='ArrayType'
+  return 'ArrayType' in type(obj).__class__.__name__
 
 def isFunctionType(obj):
-  return type(obj).__class__.__name__=='CFuncPtrType'
+  return 'CFuncPtrType' in type(obj).__class__.__name__
 
 def isCStringPointer(obj):
   return obj.__class__.__name__ == 'CString'
@@ -374,7 +376,8 @@ class LoadableMembers(ctypes.Structure):
     if isUnionType(attr):
       #log.warning('Union are not validated , yet ')
       return True
-    log.error('What type are You ?: %s'%attrname)
+    log.error('What type are You ?: %s/%s'%(attrname,attrtype))
+    printWhois(attr)
     return True
 
   def _isLoadableMember(self, attr):
@@ -670,10 +673,10 @@ class pyObj(object):
     elif not hasattr(attr,'__dict__'):
       s = '%s,'%( repr(attr) )
     elif  isinstance( attr , pyObj):
-      s = ' { %s\n},'%( attr.toString(prefix) )
+      s = '%s,'%( attr.toString(prefix) )
     else:
       s = '%s,'%(repr(attr) )
-      print 'ELSE type: %s %s'%(type(attr), type(type(attr)) )
+      #print 'ELSE type: %s %s'%(type(attr), type(type(attr)) )
     return s
 
   def findCtypes(self):
